\name{GenerateReadCount}
\alias{GenerateReadCount}
\title{
Simulation of supporting read counts detected by multiple tools
}
\description{
Generate synthetic read count matrix with rows representing fusion events and columns representing fusion detection tools.
}
\usage{
GenerateReadCount(fusionNum, toolNum, trueFusionNum, missingRate, seed)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{fusionNum}{
An integer indicating the total number of fusion events
}
  \item{toolNum}{
An integer indicating the total nubmer of fusion detection tools
}
  \item{trueFusionNum}{
An integer for the total number of true fusion events. This value should be less than or equal to \code{fusionNum}.
}
  \item{missingRate}{
A vector representing the missing detection rate of each tool. The true fusion events have 2/3 missing rate. This value shoud be in [0,1]. The length of the vector is the same as \code{toolNum}.
}
  \item{seed}{
A seed to generate random number.
}
}
\value{
\item{countMatrix}{A read count matrix with integer element (i,j) representing the number of supporting reads for fusion event i detected by tool j.}
\item{trueFusion}{A vector showing the name of true fusion events, the length of which is indicated by \code{trueFusionNum}.}
}
\references{
Comprehensive evaluation of fusion transcript detection algorithms and a meta-caller to combine top performing methods in paired-end RNA-seq data. (2015)
Silvia Liu^, Wei-Hsiang Tsai^, Ying Ding^, Rui Chen, Zhou Fang, SungHwan Kim, Tianzhou Ma, Ting-Yu Chang, Jianhua Luo, Hsei-Wei Wang*, I-Fang Chung* and George C. Tseng*.
}
\author{
Silvia Liu <silvia.shuchang.liu@gmail.com>
}

\examples{
fusionNum <- 100
toolNum <- 5
trueFusionNum <- 70  # high supporting reads
missingRate <- c(0.4,0.6,0.8,0.8,0.9)  # missing fusion rate
seed <- 12345

## simulate read counts
syn <- GenerateReadCount(fusionNum,toolNum,trueFusionNum,missingRate,seed)

## check output
syn$countMatrix
syn$trueFusion
}

